@@ -105,6 +105,7 @@ OC.L10N.register(
     "Add alias" : "Legg til alias",
     "Create alias" : "Opprett alias",
     "Cancel" : "Avbryt",
+    "Search the body of messages in priority Inbox" : "Søk i meldingsteksten i prioritert innboks",
     "Activate" : "Aktiver",
     "Remind about messages that require a reply but received none" : "Påminnelse om meldinger som krever svar, men ikke har mottatt noen",
     "Could not update preference" : "Kunne ikke oppdatere preferanse",
@@ -119,7 +120,16 @@ OC.L10N.register(
     "Sorting" : "Sorter",
     "Newest first" : "Nyeste først",
     "Oldest first" : "Eldste først",
+    "Avatars from Gravatar and favicons" : "Avatarer fra Gravatar og favicons",
+    "Reply position" : "Svarposisjon",
+    "Top" : "Toppen",
+    "Bottom" : "Bunnen",
+    "Text blocks" : "Tekstblokker",
+    "Reusable pieces of text that can be inserted in messages" : "Gjenbrukbare tekstblokker som kan settes inn i meldinger",
+    "New text block" : "Ny tekstblokk",
     "Privacy" : "Personvern",
+    "Data collection" : "Innhenting av data",
+    "Allow the app to collect and process data locally to adapt to your preferences" : "Tillat appen å samle inn og behandle data lokalt for å tilpasse seg dine preferanser",
     "Security" : "Sikkerhet",
     "S/MIME" : "S/MIME",
     "Manage certificates" : "Administrer sertifikat",
@@ -359,6 +369,7 @@ OC.L10N.register(
     "Remove {email}" : "Fjern {email}",
     "Provisioned account is disabled" : "Klargjort konto er deaktivert",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Vennligst logg inn med et passord for å aktivere denne kontoen. Den nåværende økten bruker passordløs autentisering, for eksempel SSO eller WebAuthn.",
+    "Show only subscribed folders" : "Vis kun abonnerte mapper",
     "Add folder" : "Legg til mappe",
     "Folder name" : "Mappenavn",
     "Saving" : "Lagrer",
@@ -370,9 +381,11 @@ OC.L10N.register(
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} ulest av {total}","{unread} uleste av {total}"],
     "All messages in mailbox will be deleted." : "Alle meldinger i postkassen blir slettet.",
     "Clear mailbox {name}" : "Tøm postboks {name}",
+    "Clear folder" : "Tøm mappe",
     "Delete folder" : "Slett mappe",
     "An error occurred, unable to rename the mailbox." : "Det oppsto en feil, kan ikke gi nytt navn til postboks.",
     "Mark all as read" : "Marker alle som lest",
+    "Add subfolder" : "Legg til undermappe",
     "Rename" : "Endre navn",
     "Move folder" : "Flytt mappe",
     "Clear cache" : "Tøm hurtiglager",
@@ -646,6 +659,7 @@ OC.L10N.register(
     "Private key (optional)" : "Privat nøkkel (valgfritt)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Den private nøkkelen er bare nødvendig hvis du har tenkt å sende signerte og krypterte e-postmeldinger ved hjelp av dette sertifikatet.",
     "Submit" : "Send inn",
+    "No text blocks available" : "Ingen tekstblokker tilgjengelig",
     "Group" : "Gruppe",
     "Shared" : "Delt",
     "Shares" : "Delinger",
@@ -687,6 +701,7 @@ OC.L10N.register(
     "The link leads to %s" : "Denne lenken leder til %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke vil besøke den siden, kan du gå tilbake til <a href=\"%s\">E-post</a>",
     "Continue to %s" : "Fortsett til %s",
+    "Determine importance using machine learning" : "Bestem viktighet ved hjelp av maskinlæring",
     "Last 7 days" : "Siste 7 dager",
     "From me" : "Fra meg"
 },
