@@ -10,7 +10,6 @@ declare(strict_types=1);
 namespace OCA\Mail\BackgroundJob;
 
 use OCA\Mail\Service\AccountService;
-use OCA\Mail\Service\Classification\ClassificationSettingsService;
 use OCA\Mail\Service\Classification\ImportanceClassifier;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Utility\ITimeFactory;
@@ -24,21 +23,18 @@ class TrainImportanceClassifierJob extends TimedJob {
 	private ImportanceClassifier $classifier;
 	private IJobList $jobList;
 	private LoggerInterface $logger;
-	private ClassificationSettingsService $classificationSettingsService;
 
 	public function __construct(ITimeFactory $time,
 		AccountService $accountService,
 		ImportanceClassifier $classifier,
 		IJobList $jobList,
-		LoggerInterface $logger,
-		ClassificationSettingsService $classificationSettingsService) {
+		LoggerInterface $logger) {
 		parent::__construct($time);
 
 		$this->accountService = $accountService;
 		$this->classifier = $classifier;
 		$this->jobList = $jobList;
 		$this->logger = $logger;
-		$this->classificationSettingsService = $classificationSettingsService;
 
 		$this->setInterval(24 * 60 * 60);
 		$this->setTimeSensitivity(self::TIME_INSENSITIVE);
@@ -64,7 +60,7 @@ class TrainImportanceClassifierJob extends TimedJob {
 			return;
 		}
 
-		if (!$this->classificationSettingsService->isClassificationEnabled($account->getUserId())) {
+		if (!$account->getClassificationEnabled()) {
 			$this->logger->debug("classification is turned off for account $accountId");
 			return;
 		}
