@@ -20,6 +20,7 @@ use OCA\Mail\Service\AccountService;
 use OCA\Mail\Service\AiIntegrations\AiIntegrationsService;
 use OCA\Mail\Service\AliasesService;
 use OCA\Mail\Service\Classification\ClassificationSettingsService;
+use OCA\Mail\Service\ContextChat\ContextChatSettingsService;
 use OCA\Mail\Service\InternalAddressService;
 use OCA\Mail\Service\OutboxService;
 use OCA\Mail\Service\QuickActionsService;
@@ -71,9 +72,9 @@ class PageController extends Controller {
 	private AiIntegrationsService $aiIntegrationsService;
 	private IUserManager $userManager;
 	private IAvailabilityCoordinator $availabilityCoordinator;
-	private ClassificationSettingsService $classificationSettingsService;
 	private InternalAddressService $internalAddressService;
 	private QuickActionsService $quickActionsService;
+	private ContextChatSettingsService $contextChatSettingsService;
 
 	public function __construct(
 		string $appName,
@@ -95,11 +96,12 @@ class PageController extends Controller {
 		SmimeService $smimeService,
 		AiIntegrationsService $aiIntegrationsService,
 		IUserManager $userManager,
-		ClassificationSettingsService $classificationSettingsService,
 		InternalAddressService $internalAddressService,
 		IAvailabilityCoordinator $availabilityCoordinator,
 		QuickActionsService $quickActionsService,
 		private IAppManager $appManager,
+		ContextChatSettingsService $contextChatSettingsService,
+		private ClassificationSettingsService $classificationSettingsService,
 	) {
 		parent::__construct($appName, $request);
 
@@ -120,10 +122,10 @@ class PageController extends Controller {
 		$this->smimeService = $smimeService;
 		$this->aiIntegrationsService = $aiIntegrationsService;
 		$this->userManager = $userManager;
-		$this->classificationSettingsService = $classificationSettingsService;
 		$this->internalAddressService = $internalAddressService;
 		$this->availabilityCoordinator = $availabilityCoordinator;
 		$this->quickActionsService = $quickActionsService;
+		$this->contextChatSettingsService = $contextChatSettingsService;
 	}
 
 	/**
@@ -226,13 +228,19 @@ class PageController extends Controller {
 			'collect-data' => $this->preferences->getPreference($this->currentUserId, 'collect-data', 'true'),
 			'search-priority-body' => $this->preferences->getPreference($this->currentUserId, 'search-priority-body', 'false'),
 			'start-mailbox-id' => $this->preferences->getPreference($this->currentUserId, 'start-mailbox-id'),
-			'tag-classified-messages' => $this->classificationSettingsService->isClassificationEnabled($this->currentUserId) ? 'true' : 'false',
 			'follow-up-reminders' => $this->preferences->getPreference($this->currentUserId, 'follow-up-reminders', 'true'),
+			'sort-favorites' => $this->preferences->getPreference($this->currentUserId, 'sort-favorites', 'false'),
+			'index-context-chat' => $this->contextChatSettingsService->isIndexingEnabled($this->currentUserId) ? 'true' : 'false',
+			'compact-mode' => $this->preferences->getPreference($this->currentUserId, 'compact-mode', 'false'),
 		]);
 		$this->initialStateService->provideInitialState(
 			'prefill_displayName',
 			$this->userManager->getDisplayName($this->currentUserId),
 		);
+		$this->initialStateService->provideInitialState(
+			'importance_classification_default',
+			$this->classificationSettingsService->isClassificationEnabledByDefault(),
+		);
 		$this->initialStateService->provideInitialState(
 			'prefill_email',
 			$this->config->getUserValue($user->getUID(), 'settings', 'email', '')
@@ -318,6 +326,11 @@ class PageController extends Controller {
 			&& $this->aiIntegrationsService->isLlmAvailable(FreePromptTaskType::class)
 		);
 
+		$this->initialStateService->provideInitialState(
+			'context_chat_available',
+			$this->appManager->isEnabledForUser('context_chat')
+		);
+
 		$this->initialStateService->provideInitialState(
 			'smime-certificates',
 			array_map(
